==> kryptokrona-util-0.2.0-sources.jar: org/kryptokrona/sdk/util/model/transaction/RawTransaction.kt <==
// Copyright (c) 2022-2023, The Kryptokrona Developers
//
// Written by Marcus Cvjeticanin
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice, this list of
//    conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice, this list
//    of conditions and the following disclaimer in the documentation and/or other
//    materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors may be
//    used to endorse or promote products derived from this software without specific
//    prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
// THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
// THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package org.kryptokrona.sdk.util.model.transaction

import org.kryptokrona.sdk.util.model.output.KeyInput
import org.kryptokrona.sdk.util.model.output.KeyOutput

/**
 * Raw coinbase transaction.
 *
 * @author Marcus Cvjeticanin
 * @since 0.1.0
 * @param keyOutputs List of key outputs.
 * @param hash Transaction hash.
 * @param transactionPublishKey Transaction publish key.
 * @param unlockTime Transaction unlock time.
 * @param paymentId Payment ID.
 * @param keyInputs List of key inputs.
 * @see RawCoinbaseTransaction
 */
data class RawTransaction(
    override var keyOutputs: List<KeyOutput>,
    override val hash: String,
    override val transactionPublishKey: String,
    override val unlockTime: Long,
    val paymentId: String,
    val keyInputs: List<KeyInput>,
) : RawCoinbaseTransaction

==> kryptokrona-util-0.3.0-sources.jar: org/kryptokrona/sdk/util/model/transaction/RawTransaction.kt <==
// Copyright (c) 2022-2023, The Kryptokrona Developers
//
// Written by Marcus Cvjeticanin
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice, this list of
//    conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice, this list
//    of conditions and the following disclaimer in the documentation and/or other
//    materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors may be
//    used to endorse or promote products derived from this software without specific
//    prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
// THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
// THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package org.kryptokrona.sdk.util.model.transaction

import org.kryptokrona.sdk.util.model.input.KeyInput
import org.kryptokrona.sdk.util.model.output.KeyOutput

/**
 * Raw coinbase transaction.
 *
 * @author Marcus Cvjeticanin
 * @since 0.1.0
 * @param keyOutputs List of key outputs.
 * @param hash Transaction hash.
 * @param transactionPublishKey Transaction publish key.
 * @param unlockTime Transaction unlock time.
 * @param paymentId Payment ID.
 * @param keyInputs List of key inputs.
 * @see RawCoinbaseTransaction
 */
data class RawTransaction(
    override var keyOutputs: List<KeyOutput>,
    override val hash: String,
    override val transactionPublishKey: String,
    override val unlockTime: Long,
    val paymentId: String,
    val keyInputs: List<KeyInput>,
) : RawCoinbaseTransaction
